@@ -7,6 +7,15 @@ from numpy.testing import assert_array_equal, assert_almost_equal
 
 from mpi4py_test import MPIWorld
 
+from mpi4py import MPI
+def test_wrold():
+    world = MPI.COMM_WORLD
+
+    procmesh = pfft.ProcMesh(np=[world.size,], comm=world)
+    assert procmesh.comm == world
+    procmesh = pfft.ProcMesh(np=[world.size,], comm=None)
+    assert procmesh.comm == world
+
 @MPIWorld(NTask=3, required=3, optional=True)
 def test_edges(comm):
     procmesh = pfft.ProcMesh(np=[comm.size,], comm=comm)
